summaryrefslogtreecommitdiffhomepage
path: root/dev/LibDebugger/POSIX.h
diff options
context:
space:
mode:
Diffstat (limited to 'dev/LibDebugger/POSIX.h')
-rw-r--r--dev/LibDebugger/POSIX.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/dev/LibDebugger/POSIX.h b/dev/LibDebugger/POSIX.h
index 52af66e..b863f58 100644
--- a/dev/LibDebugger/POSIX.h
+++ b/dev/LibDebugger/POSIX.h
@@ -34,17 +34,17 @@ namespace LibDebugger::POSIX
typedef char* CAddr;
#endif
/// \brief Debugger engine interface class in C++
/// \author Amlal El Mahrouss
- class Debugger final
+ class LocalDebuggerPOSIX final
{
public:
- explicit Debugger() = default;
- ~Debugger() = default;
+ explicit LocalDebuggerPOSIX() = default;
+ ~LocalDebuggerPOSIX() = default;
public:
- Debugger& operator=(const Debugger&) = default;
- Debugger(const Debugger&) = default;
+ LocalDebuggerPOSIX& operator=(const LocalDebuggerPOSIX&) = default;
+ LocalDebuggerPOSIX(const LocalDebuggerPOSIX&) = default;
public:
bool Attach(pid_t pid)
@@ -34,17 +34,17 @@ namespace LibDebugger::POSIX
typedef char* CAddr;
#endif
- /// \brief Debugger engine interface class in C++
+ /// \brief LocalDebuggerPOSIX engine interface class in C++
/// \author Amlal El Mahrouss